@@ -56,11 +56,11 @@
 					(get-redeals-string))))
 
 (define (get-stock-no-string)
-  (string-append (gettext "Stock left:  ") 
+  (string-append (_"Stock left:") " " 
 		 (number->string (length (get-cards 8)))))
 
 (define (get-redeals-string)
-  (string-append (gettext "Redeals left:  ")
+  (string-append (_"Redeals left:") " "
 		 (number->string (- 2 FLIP-COUNTER))))
 
 (define (button-pressed slot-id card-list)
@@ -165,7 +165,7 @@
        (or (if (empty-slot? slot-id)
 	       (and (= (get-value card) 
 		       (get-value (car (reverse (get-cards 1)))))
-		    (list 1 (get-name card) (gettext "an empty slot")))
+		    (list 1 (get-name card) (_"an empty slot")))
 	       (and (= (get-suit card) (get-suit (get-top-card slot-id)))
 		    (or (= slot-id 1)
 			(find-card-val-in-list? (get-cards (- slot-id 2)) 
@@ -195,7 +195,7 @@
 
 (define (get-hint)
   (or (get-valid-move '(0 2 4 6 9))
-      (list 0 (gettext "Deal a new card from the deck"))))
+      (list 0 (_"Deal a new card from the deck"))))
 
 (define (get-options) #f)
 
