@@ -990,7 +990,7 @@ session_management_init (void)
 		      GTK_SIGNAL_FUNC (preferences_save_local), 
 		      GINT_TO_POINTER (FALSE));
   g_signal_connect (GTK_OBJECT (client), "die",
-		      GTK_SIGNAL_FUNC (gstones_exit), NULL);
+		      GTK_SIGNAL_FUNC (quit_cb), NULL);
 }
 
 
